<?php
/* @var $this NewsletterElasticEmail */

require_once NEWSLETTER_INCLUDES_DIR . '/controls.php';
$controls = new NewsletterControls();
$mailer = $this->get_mailer();

if (!$controls->is_action()) {
    $controls->data = $this->options;
} else {

    if ($controls->is_action('save')) {
        $this->save_options($controls->data);
        $controls->add_message_saved();
    }

    if ($controls->is_action('trigger')) {
        $res = $this->bounce();
        if (!empty($this->bounce_result)) {
            $controls->errors = $this->bounce_result;
        } else {
            $controls->messages = 'Done.<br> Found ' . count($this->bounce_emails) . ' bounces.<br>' . implode(', ', $this->bounce_emails) . '<br><br>' .
                    'Found ' . count($this->unsubscribed_emails) . ' unsubscriptions.<br>' . implode(', ', $this->unsubscribed_emails);
        }
    }

    if ($controls->is_action('reset')) {
        $this->save_last_run(0);
        $controls->add_message_done();
    }

    if ($controls->is_action('test')) {
        if (!empty($this->options['turbo'])) {
            $messages = $this->get_test_messages($controls->data['test_email'], $this->options['turbo']);

            $r = $mailer->send_batch_with_stats($messages);

            if (is_wp_error($r)) {
                $controls->errors .= '<strong>Delivery error: ' . $r->get_error_message() . '</strong><br>';
                foreach ($messages as $message) {
                    $controls->errors .= 'Error: ' . esc_html($message->error) . '<br>';
                }
            } else {
                $controls->messages = 'Success. You should see ' . $this->options['turbo'] . ' test messages in ElastEmail console panel and in the selected mailbox.';
                $controls->messages .= '<br>Max speed: ' . $mailer->get_capability() . ' emails per hour';
            }
        } else {
            $message = $this->get_test_message($controls->data['test_email']);
            $result = $mailer->send_with_stats($message);
            if (is_wp_error($result)) {
                $controls->errors .= 'Delivery error: ' . $result->get_error_message() . '<br>';
            } else {
                $controls->messages = 'Success. You should see the test message in ElastEmail console panel.';
                $controls->messages .= '<br>Max speed: ' . $mailer->get_capability() . ' emails per hour';
            }
        }
    }
}

if (!isset($controls->data['enabled'])) {
    $controls->warnings[] = 'The extension is not enabled. After you configured and tested it, remember to enable it.';
}

$current_mailer = Newsletter::instance()->get_mailer();
if (isset($controls->data['enabled']) && get_class($current_mailer) != get_class($mailer) && !empty($controls->data['enabled'])) {
    $controls->warnings[] = 'There is another integration active ' . $current_mailer->get_description();
}

if (class_exists('NewsletterBounce')) {
    $controls->warnings[] = 'The Bounce Addon is active, but bounces are managed by this addon: you can save some resources deactivating it.';
}
?>

<div class="wrap" id="tnp-wrap">
    <?php @include NEWSLETTER_DIR . '/tnp-header.php' ?>
    <div id="tnp-heading">
        <h2>Elastic Email</h2>

        <?php $controls->show(); ?>

    </div>
    <div id="tnp-body">
        <form action="" method="post">
            <?php $controls->init(); ?>

            <div id="tabs">
                <ul>
                    <li><a href="#tabs-general">Delivery</a></li>
                    <li><a href="#tabs-bounces">Bounces</a></li>
                </ul>

                <div id="tabs-general">

                    <table class="form-table">
                        <tr valign="top">
                            <th>Enabled?</th>
                            <td>
                                <?php $controls->yesno('enabled'); ?>
                                <p class="description">You can do tests without enabling it</p>
                            </td>
                        </tr>

                        <tr valign="top">
                            <th>API Key</th>
                            <td>
                                <?php $controls->text('api_key', 50); ?>
                                <p class="description"></p>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th>Text part</th>
                            <td>
                                <?php $controls->disabled('disable_text_part'); ?>
                                <p class="description">Disable the email text part (so you can use the automatic Elastic Email text part)</p>
                            </td>
                        </tr>
                        <tr>
                            <th>
                                Turbo send
                            </th>
                            <td>
                                <?php
                                $controls->select('turbo', array('' => 'Disabled',
                                    '2' => '2 processors',
                                    '3' => '3 processors',
                                    '4' => '4 processors',
                                    '5' => '5 processors',
                                    '6' => '6 processors',
                                    '7' => '7 processors',
                                    '8' => '8 processors',
                                    '9' => '9 processors',
                                    '10' => '10 processors'));
                                ?>
                                (read carefully the help page)
                            </td>
                        </tr>
                        <tr>
                            <th>To test this configuration</th>
                            <td>
                                <?php $controls->text('test_email', 30); ?>
                                <?php $controls->button('test', 'Send a message to this email'); ?>
                            </td>
                        </tr>
                    </table>
                </div>


                <div id="tabs-bounces">
                    <table class="form-table">
                        <tr valign="top">
                            <th>Bounce checking last run</th>
                            <td>
                                <?php echo $controls->print_date($this->get_last_run()); ?>
                                <?php $controls->button('trigger', 'Check now'); ?>
                                <?php $controls->button('reset', 'Reset last check time'); ?>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th>Bounce checking next run</th>
                            <td>
                                <?php echo $controls->print_date(wp_next_scheduled('newsletter_elasticemail_bounce')); ?>
                            </td>
                        </tr>
                    </table>

                </div>

            </div>

            <p>
                <?php $controls->button('save', 'Save'); ?>
            </p>
        </form>
    </div>
    <?php @include NEWSLETTER_DIR . '/tnp-footer.php' ?>
</div>